Exception: Hitch::MCP::Forbidden

Inherits:
StandardError
  • Object
show all
Defined in:
app/models/hitch/mcp/forbidden.rb

Overview

Raised by host argument policy to deny one otherwise admissible tool call. Its message is always private and never crosses the MCP boundary.